@@ -1,7 +1,10 @@
 package Test2::Require::TestCorpus;
 
+use v5.20;
 use strict;
 use warnings;
+use feature qw(signatures);
+no warnings qw(experimental::signatures);
 
 use Test2::Require::Module qw(File::BaseDir);
 
@@ -11,11 +14,8 @@ use Carp qw/confess/;
 
 use base 'Test2::Require';
 
-sub skip
+sub skip ( $class, $var )
 {
-	my $class = shift;
-	my ($var) = @_;
-	confess 'no test corpus variable specified' unless $var;
 	return undef if data_dirs("tests/$var");
 	return
 		"This test only runs if test corpus is available at the path \${XDG_DATA_DIRS} + tests/$var/";
